/*
 * OCSP responder
 * by Massimiliano Pala (madwolf@openca.org)
 * OpenCA project 2001
 *
 * Copyright (c) 2001 The OpenCA Project.  All rights reserved.
 *
 * ====================================================================
 *
 * This product includes cryptographic software written by Eric Young
 * (eay@cryptsoft.com).  This product includes software written by Tim
 * Hudson (tjh@cryptsoft.com).
 *
 */

#include "general.h"
#include <openssl/txt_db.h>
#include <openssl/conf.h>

#include "support.h"
#include "configuration.h"

/* External imported variables */
extern int verbose;

/* Functions */

CONF *load_config( char *configfile, char **section ) {

	CONF *conf;
	long errorline= -1;

        if (configfile == NULL) configfile = getenv("OCSP_CONF");
        if (configfile == NULL) configfile = CONFIG_FILE;
        if (configfile == NULL) return(NULL);

        syslog(LOG_INFO,"Using configuration from %s\n",configfile);
	conf = NCONF_new(NULL);
        if ( NCONF_load(conf, configfile, &errorline) <= 0 )
                {
                if (errorline <= 0)
                        syslog(LOG_ERR,
				"error loading the config file '%s'\n",
                                configfile);
                else
                        syslog(LOG_ERR,
				"error on line %ld of config file '%s'\n"
                                ,errorline, configfile);
                return(NULL);
                }

        if (*section == NULL) {
                *section=NCONF_get_string(conf,BASE_SECTION,ENV_DEFAULT_OCSPD);
                if (*section == NULL) {
                        lookup_fail(BASE_SECTION,ENV_DEFAULT_OCSPD);
                        return(NULL);
                }
		setenv( ENV_SECTION, *section, 1);
		if( verbose )
			syslog(LOG_INFO,"section set to %s", *section );
        }

	return(conf);
}

